@@ -32,37 +32,34 @@ def savebackup(path, output, exclude, token):
     configpath = path + "/" + "Device Configurations/"
     data = makeapirequest(ENDPOINT, token)
 
-    assignment_responses = batch_assignment(
-        data, 'deviceManagement/deviceConfigurations/', '/assignments', token)
+    assignment_responses = batch_assignment(data, "deviceManagement/deviceConfigurations/", "/assignments", token)
 
-    for profile in data['value']:
+    for profile in data["value"]:
         config_count += 1
         if "assignments" not in exclude:
-            assignments = get_object_assignment(
-                profile['id'], assignment_responses)
+            assignments = get_object_assignment(profile["id"], assignment_responses)
             if assignments:
-                profile['assignments'] = assignments
+                profile["assignments"] = assignments
 
-        pid = profile['id']
+        pid = profile["id"]
         profile = remove_keys(profile)
 
-        print("Backing up profile: " + profile['displayName'])
+        print("Backing up profile: " + profile["displayName"])
 
         # Get filename without illegal characters
-        fname = clean_filename(
-            f"{profile['displayName']}_{str(profile['@odata.type']).split('.')[2]}")
+        fname = clean_filename(f"{profile['displayName']}_{str(profile['@odata.type']).split('.')[2]}")
 
         # If profile is custom macOS or iOS, decode the payload
-        if ((profile['@odata.type'] == "#microsoft.graph.macOSCustomConfiguration")
-                or (profile['@odata.type'] == "#microsoft.graph.iosCustomConfiguration")):
-            decoded = base64.b64decode(profile['payload']).decode('utf-8')
+        if (profile["@odata.type"] == "#microsoft.graph.macOSCustomConfiguration") or (
+            profile["@odata.type"] == "#microsoft.graph.iosCustomConfiguration"
+        ):
+            decoded = base64.b64decode(profile["payload"]).decode("utf-8")
 
-            if not os.path.exists(configpath + '/' + "mobileconfig/"):
-                os.makedirs(configpath + '/' + "mobileconfig/")
+            if not os.path.exists(configpath + "/" + "mobileconfig/"):
+                os.makedirs(configpath + "/" + "mobileconfig/")
             # Save decoded payload as .mobileconfig
             config_count += 1
-            f = open(configpath + '/' + "mobileconfig/" +
-                     profile['payloadFileName'], 'w')
+            f = open(configpath + "/" + "mobileconfig/" + profile["payloadFileName"], "w")
             f.write(decoded)
             # Save Device Configuration as JSON or YAML depending on configured
             # value in "-o"
@@ -70,34 +67,35 @@ def savebackup(path, output, exclude, token):
 
         # If Device Configuration is custom Win10 and the OMA settings are
         # encrypted, get them in plain text
-        elif profile['@odata.type'] == "#microsoft.graph.windows10CustomConfiguration":
-            if profile['omaSettings']:
-                if profile['omaSettings'][0]['isEncrypted'] is True:
+        elif profile["@odata.type"] == "#microsoft.graph.windows10CustomConfiguration":
+            if profile["omaSettings"]:
+                if profile["omaSettings"][0]["isEncrypted"] is True:
 
                     omas = []
-                    for setting in profile['omaSettings']:
-                        if setting['isEncrypted']:
+                    for setting in profile["omaSettings"]:
+                        if setting["isEncrypted"]:
                             decoded_oma = {}
                             oma_value = makeapirequest(
-                                ENDPOINT +
-                                "/" +
-                                pid +
-                                "/getOmaSettingPlainTextValue(secretReferenceValueId='" +
-                                setting['secretReferenceValueId'] +
-                                "')",
-                                token)
-                            decoded_oma['@odata.type'] = setting['@odata.type']
-                            decoded_oma['displayName'] = setting['displayName']
-                            decoded_oma['description'] = setting['description']
-                            decoded_oma['omaUri'] = setting['omaUri']
-                            decoded_oma['value'] = oma_value
-                            decoded_oma['isEncrypted'] = False
-                            decoded_oma['secretReferenceValueId'] = None
+                                ENDPOINT
+                                + "/"
+                                + pid
+                                + "/getOmaSettingPlainTextValue(secretReferenceValueId='"
+                                + setting["secretReferenceValueId"]
+                                + "')",
+                                token,
+                            )
+                            decoded_oma["@odata.type"] = setting["@odata.type"]
+                            decoded_oma["displayName"] = setting["displayName"]
+                            decoded_oma["description"] = setting["description"]
+                            decoded_oma["omaUri"] = setting["omaUri"]
+                            decoded_oma["value"] = oma_value
+                            decoded_oma["isEncrypted"] = False
+                            decoded_oma["secretReferenceValueId"] = None
                             decoded_omas = decoded_oma
                             omas.append(decoded_omas)
 
-                    profile.pop('omaSettings')
-                    profile['omaSettings'] = omas
+                    profile.pop("omaSettings")
+                    profile["omaSettings"] = omas
 
             # Save Device Configuration as JSON or YAML depending on configured
             # value in "-o"
