@@ -19,55 +19,76 @@ def makeapirequest(endpoint, token, q_param=None):
     :return: The response from the request.
     """
 
-    headers = {'Content-Type': 'application/json',
-               'Authorization': 'Bearer {0}'.format(token['accessToken'])}
+    headers = {
+        "Content-Type": "application/json",
+        "Authorization": "Bearer {0}".format(token["access_token"]),
+    }
 
     if q_param is not None:
         response = requests.get(endpoint, headers=headers, params=q_param)
-        if response.status_code == 504 or response.status_code == 502 or response.status_code == 503:
-            print('Ran into issues with Graph request, waiting 10 seconds and trying again...')
+        if (
+            response.status_code == 504
+            or response.status_code == 502
+            or response.status_code == 503
+        ):
+            print(
+                "Ran into issues with Graph request, waiting 10 seconds and trying again..."
+            )
             time.sleep(10)
             response = requests.get(endpoint, headers=headers)
         elif response.status_code == 429:
-            print(f"Hit Graph throttling, trying again after {response.headers['Retry-After']} seconds")
+            print(
+                f"Hit Graph throttling, trying again after {response.headers['Retry-After']} seconds"
+            )
             while response.status_code == 429:
-                time.sleep(int(response.headers['Retry-After']))
-                response = requests.get(endpoint, headers=headers)   
+                time.sleep(int(response.headers["Retry-After"]))
+                response = requests.get(endpoint, headers=headers)
     else:
         response = requests.get(endpoint, headers=headers)
-        if response.status_code == 504 or response.status_code == 502 or response.status_code == 503:
-            print('Ran into issues with Graph request, waiting 10 seconds and trying again...')
+        if (
+            response.status_code == 504
+            or response.status_code == 502
+            or response.status_code == 503
+        ):
+            print(
+                "Ran into issues with Graph request, waiting 10 seconds and trying again..."
+            )
             time.sleep(10)
             response = requests.get(endpoint, headers=headers)
         elif response.status_code == 429:
-            print(f"Hit Graph throttling, trying again after {response.headers['Retry-After']} seconds")
+            print(
+                f"Hit Graph throttling, trying again after {response.headers['Retry-After']} seconds"
+            )
             while response.status_code == 429:
-                time.sleep(int(response.headers['Retry-After']))
-                response = requests.get(endpoint, headers=headers)            
+                time.sleep(int(response.headers["Retry-After"]))
+                response = requests.get(endpoint, headers=headers)
 
     if response.status_code == 200:
         json_data = json.loads(response.text)
 
-        if '@odata.nextLink' in json_data.keys():
-            record = makeapirequest(json_data['@odata.nextLink'], token)
-            entries = len(record['value'])
+        if "@odata.nextLink" in json_data.keys():
+            record = makeapirequest(json_data["@odata.nextLink"], token)
+            entries = len(record["value"])
             count = 0
             while count < entries:
-                json_data['value'].append(record['value'][count])
+                json_data["value"].append(record["value"][count])
                 count += 1
 
-        return (json_data)
+        return json_data
 
     elif response.status_code == 404:
         print("Resource not found in Microsoft Graph: " + endpoint)
     elif ("assignmentFilters" in endpoint) and ("FeatureNotEnabled" in response.text):
         print("Assignment filters not enabled in tenant, skipping")
     else:
-        raise Exception('Request failed with ', response.status_code, ' - ',
-                        response.text)
+        raise Exception(
+            "Request failed with ", response.status_code, " - ", response.text
+        )
 
 
-def makeapirequestPatch(patchEndpoint, token, q_param=None, jdata=None, status_code=200):
+def makeapirequestPatch(
+    patchEndpoint, token, q_param=None, jdata=None, status_code=200
+):
     """
     This function makes a PATCH request to the Microsoft Graph API.
 
@@ -78,18 +99,23 @@ def makeapirequestPatch(patchEndpoint, token, q_param=None, jdata=None, status_c
     :param status_code: The status code to expect from the request.
     """
 
-    headers = {'Content-Type': 'application/json',
-               'Authorization': 'Bearer {0}'.format(token['accessToken'])}
+    headers = {
+        "Content-Type": "application/json",
+        "Authorization": "Bearer {0}".format(token["access_token"]),
+    }
 
     if q_param is not None:
-        response = requests.patch(patchEndpoint, headers=headers, params=q_param, data=jdata)
+        response = requests.patch(
+            patchEndpoint, headers=headers, params=q_param, data=jdata
+        )
     else:
         response = requests.patch(patchEndpoint, headers=headers, data=jdata)
     if response.status_code == status_code:
         pass
     else:
-        raise Exception('Request failed with ', response.status_code, ' - ',
-                        response.text)
+        raise Exception(
+            "Request failed with ", response.status_code, " - ", response.text
+        )
 
 
 def makeapirequestPost(patchEndpoint, token, q_param=None, jdata=None, status_code=200):
@@ -103,11 +129,15 @@ def makeapirequestPost(patchEndpoint, token, q_param=None, jdata=None, status_co
     :param status_code: The status code to expect from the request.
     """
 
-    headers = {'Content-Type': 'application/json',
-               'Authorization': 'Bearer {0}'.format(token['accessToken'])}
+    headers = {
+        "Content-Type": "application/json",
+        "Authorization": "Bearer {0}".format(token["access_token"]),
+    }
 
     if q_param is not None:
-        response = requests.post(patchEndpoint, headers=headers, params=q_param, data=jdata)
+        response = requests.post(
+            patchEndpoint, headers=headers, params=q_param, data=jdata
+        )
     else:
         response = requests.post(patchEndpoint, headers=headers, data=jdata)
     if response.status_code == status_code:
@@ -116,9 +146,17 @@ def makeapirequestPost(patchEndpoint, token, q_param=None, jdata=None, status_co
             return json_data
         else:
             pass
+    elif response.status_code == 429:
+        print(
+            f"Hit Graph throttling, trying again after {response.headers['Retry-After']} seconds"
+        )
+        while response.status_code == 429:
+            time.sleep(int(response.headers["Retry-After"]))
+            response = requests.post(patchEndpoint, headers=headers, data=jdata)
     else:
-        raise Exception('Request failed with ', response.status_code, ' - ',
-                        response.text)
+        raise Exception(
+            "Request failed with ", response.status_code, " - ", response.text
+        )
 
 
 def makeapirequestPut(patchEndpoint, token, q_param=None, jdata=None, status_code=200):
@@ -132,15 +170,20 @@ def makeapirequestPut(patchEndpoint, token, q_param=None, jdata=None, status_cod
     :param status_code: The status code to expect from the request.
     """
 
-    headers = {'Content-Type': 'application/json',
-               'Authorization': 'Bearer {0}'.format(token['accessToken'])}
+    headers = {
+        "Content-Type": "application/json",
+        "Authorization": "Bearer {0}".format(token["access_token"]),
+    }
 
     if q_param is not None:
-        response = requests.put(patchEndpoint, headers=headers, params=q_param, data=jdata)
+        response = requests.put(
+            patchEndpoint, headers=headers, params=q_param, data=jdata
+        )
     else:
         response = requests.put(patchEndpoint, headers=headers, data=jdata)
     if response.status_code == status_code:
         pass
     else:
-        raise Exception('Request failed with ', response.status_code, ' - ',
-                        response.text)
+        raise Exception(
+            "Request failed with ", response.status_code, " - ", response.text
+        )
