@@ -32,19 +32,18 @@ REPO_DIR = os.environ.get("REPO_DIR")
 
 
 def start():
-    parser = argparse.ArgumentParser(
-        description="Save backup of Intune configurations")
+    parser = argparse.ArgumentParser(description="Save backup of Intune configurations")
     parser.add_argument(
         "-o",
         "--output",
-        help='The format backups will be saved as, valid options are json or yaml. Default is json',
+        help="The format backups will be saved as, valid options are json or yaml. Default is json",
         type=str,
         default="json",
     )
     parser.add_argument(
         "-p",
         "--path",
-        help='The path to which the configurations will be saved. Default value is $(Build.SourcesDirectory)',
+        help="The path to which the configurations will be saved. Default value is $(Build.SourcesDirectory)",
         type=str,
         default=REPO_DIR,
     )
@@ -54,17 +53,33 @@ def start():
         help=(
             "The mode in which the script is run, 0 = devtoprod (backup from dev -> update to prod) "
             "uses os.environ DEV_TENANT_NAME, DEV_CLIENT_ID, DEV_CLIENT_SECRET, "
-            "1 = standalone (backup from prod) uses os.environ TENANT_NAME, CLIENT_ID, CLIENT_SECRET"),
+            "1 = standalone (backup from prod) uses os.environ TENANT_NAME, CLIENT_ID, CLIENT_SECRET"
+        ),
         type=int,
-        default=0)
+        default=0,
+    )
     parser.add_argument(
         "-a",
         "--localauth",
         help=(
             "When this paramater is set, provide a path to a local dict file containing the following keys: "
             "params:TENANT_NAME, CLIENT_ID, CLIENT_SECRET when run in standalone mode and "
-            "params:DEV_TENANT_NAME, DEV_CLIENT_ID, DEV_CLIENT_SECRET when run in devtoprod"),
-        type=str)
+            "params:DEV_TENANT_NAME, DEV_CLIENT_ID, DEV_CLIENT_SECRET when run in devtoprod"
+        ),
+        type=str,
+    )
+    parser.add_argument(
+        "-c",
+        "--certauth",
+        help="When using certificate auth, the following ENV variables is required: TENANT_NAME, CLIENT_ID, THUMBPRINT, KEY_FILE",
+        action="store_true",
+    )
+    parser.add_argument(
+        "-i",
+        "--interactiveauth",
+        help="When using interactive auth, the following ENV variables is required: TENANT_NAME, CLIENT_ID",
+        action="store_true",
+    )
     parser.add_argument(
         "-e",
         "--exclude",
@@ -93,16 +108,21 @@ def start():
             "PowershellScripts",
             "ShellScripts",
             "ConfigurationPolicies",
-            "ConditionalAccess"],
-        nargs='+')
+            "ConditionalAccess",
+            "EnrollmentConfigurations",
+        ],
+        nargs="+",
+    )
     parser.add_argument(
         "-f",
         "--frontend",
         help="Set the frontend URL to update with configuration count and backup stream",
-        type=str)
+        type=str,
+    )
     parser.add_argument(
-        "-ap", "--autopilot",
-        help="If set to True, a record of autopilot devices will be saved"
+        "-ap",
+        "--autopilot",
+        help="If set to True, a record of autopilot devices will be saved",
     )
 
     args = parser.parse_args()
@@ -113,123 +133,162 @@ def start():
     def standalone():
         return "standalone"
 
-    switcher = {
-        0: devtoprod,
-        1: standalone
-    }
+    switcher = {0: devtoprod, 1: standalone}
 
     def selected_mode(argument):
         func = switcher.get(argument, "nothing")
         return func()
 
-    token = getAuth(selected_mode(args.mode), args.localauth, tenant="DEV")
+    if args.certauth or args.interactiveauth:
+        args.mode = None
+    else:
+        args.mode = selected_mode(args.mode)
+
+    token = getAuth(
+        args.mode,
+        args.localauth,
+        args.certauth,
+        args.interactiveauth,
+        tenant="DEV",
+    )
 
     def run_backup(path, output, exclude, token):
-
         config_count = 0
 
         if "AppConfigurations" not in exclude:
             from .backup_appConfiguration import savebackup
+
             config_count += savebackup(path, output, exclude, token)
 
         if "AppProtection" not in exclude:
             from .backup_AppProtection import savebackup
+
             config_count += savebackup(path, output, exclude, token)
 
         if "APNs" not in exclude:
             from .backup_apns import savebackup
+
             config_count += savebackup(path, output, token)
 
         if "VPP" not in exclude:
             from .backup_vppTokens import savebackup
+
             config_count += savebackup(path, output, token)
 
         if "Applications" not in exclude:
             from .backup_applications import savebackup
+
             config_count += savebackup(path, output, exclude, token)
 
         if "Compliance" not in exclude:
             from .backup_compliance import savebackup
+
             config_count += savebackup(path, output, exclude, token)
 
         if "NotificationTemplate" not in exclude:
             from .backup_notificationTemplate import savebackup
+
             config_count += savebackup(path, output, token)
 
         if "Profiles" not in exclude:
             from .backup_profiles import savebackup
+
             config_count += savebackup(path, output, exclude, token)
 
         if "GPOConfigurations" not in exclude:
             from .backup_groupPolicyConfiguration import savebackup
+
             config_count += savebackup(path, output, exclude, token)
 
         if "AppleEnrollmentProfile" not in exclude:
             from .backup_appleEnrollmentProfile import savebackup
+
             config_count += savebackup(path, output, token)
 
         if "WindowsEnrollmentProfile" not in exclude:
             from .backup_windowsEnrollmentProfile import savebackup
+
             config_count += savebackup(path, output, exclude, token)
 
         if "EnrollmentStatusPage" not in exclude:
             from .backup_enrollmentStatusPage import savebackup
+
             config_count += savebackup(path, output, exclude, token)
-        
+
+        if "EnrollmentConfigurations" not in exclude:
+            from .backup_enrollmentConfigurations import savebackup
+
+            config_count += savebackup(path, output, exclude, token)
+
         if args.autopilot == "True":
             from .backup_autopilotDevices import savebackup
+
             savebackup(path, output, token)
 
         if "Filters" not in exclude:
             from .backup_assignmentFilters import savebackup
+
             config_count += savebackup(path, output, token)
 
         if "ManagedGooglePlay" not in exclude:
             from .backup_managedGPlay import savebackup
+
             config_count += savebackup(path, output, token)
 
         if "Intents" not in exclude:
             from .backup_managementIntents import savebackup
+
             config_count += savebackup(path, output, exclude, token)
 
         if "CompliancePartner" not in exclude:
             from .backup_compliancePartner import savebackup
+
             config_count += savebackup(path, output, token)
 
         if "ManagementPartner" not in exclude:
             from .backup_managementPartner import savebackup
+
             config_count += savebackup(path, output, token)
 
         if "RemoteAssistancePartner" not in exclude:
             from .backup_remoteAssistancePartner import savebackup
+
             config_count += savebackup(path, output, token)
 
         if "ProactiveRemediation" not in exclude:
             from .backup_proactiveRemediation import savebackup
+
             config_count += savebackup(path, output, exclude, token)
 
         if "PowershellScripts" not in exclude:
             from .backup_powershellScripts import savebackup
+
             config_count += savebackup(path, output, exclude, token)
 
         if "ShellScripts" not in exclude:
             from .backup_shellScripts import savebackup
+
             config_count += savebackup(path, output, exclude, token)
 
         if "ConfigurationPolicies" not in exclude:
             from .backup_configurationPolicies import savebackup
+
             config_count += savebackup(path, output, exclude, token)
 
         if "ConditionalAccess" not in exclude:
             from .backup_conditionalAccess import savebackup
+
             config_count += savebackup(path, output, token)
 
+        from .assignment_report import get_group_report
+
+        get_group_report(path, output)
+
         return config_count
 
-    if args.output == 'json' or args.output == 'yaml':
+    if args.output == "json" or args.output == "yaml":
         if token is None:
-            raise Exception(
-                "Token is empty, please check os.environ variables")
+            raise Exception("Token is empty, please check os.environ variables")
 
         if args.exclude:
             exclude = args.exclude
@@ -237,7 +296,6 @@ def start():
             exclude = []
 
         if args.frontend:
-
             old_stdout = sys.stdout
             sys.stdout = feedstdout = StringIO()
             count = run_backup(args.path, args.output, exclude, token)
@@ -245,23 +303,45 @@ def start():
             feed_bytes = feedstdout.getvalue().encode("utf-8")
             out = base64.b64encode(feed_bytes).decode("utf-8")
 
-            body = {
-                "type": "config_count",
-                "config_count": count
-            }
-            update_frontend(f'{args.frontend}/api/overview/summary', body)
+            body = {"type": "config_count", "config_count": count}
+            update_frontend(f"{args.frontend}/api/overview/summary", body)
 
-            body = {
-                "type": "backup",
-                "feed": out
-            }
-            update_frontend(f'{args.frontend}/api/feed/update', body)
+            body = {"type": "backup", "feed": out}
+            update_frontend(f"{args.frontend}/api/feed/update", body)
+
+            body = []
+
+            from .load_file import load_file
+            from .check_file import check_file
+
+            config_path = f"{args.path}/Assignment Report"
+            file_name = f"report.{args.output}"
+            if os.path.exists(config_path):
+                file_check = check_file(config_path, file_name)
+                if file_check:
+                    with open(f"{config_path}/{file_name}", "r") as f:
+                        assignment_summary = load_file(file_name, f)
+                    if assignment_summary:
+                        for assignment in assignment_summary:
+                            body.append(
+                                {
+                                    "groupName": assignment["groupName"],
+                                    "groupType": assignment["groupType"],
+                                    "membershipRule": assignment["membershipRule"],
+                                    "assignedTo": assignment["assignedTo"],
+                                }
+                            )
+
+                        if len(body) > 0:
+                            update_frontend(
+                                f"{args.frontend}/api/assignments/summary", body
+                            )
 
         else:
             run_backup(args.path, args.output, exclude, token)
 
     else:
-        print('Please enter a valid output format, json or yaml')
+        print("Please enter a valid output format, json or yaml")
 
 
 if __name__ == "__main__":
